local HerbsAndOreTest = {}
HerbsAndOreTest.__index = HerbsAndOreTest

setmetatable(HerbsAndOreTest, {
  __index = UnitTest, -- this is what makes the inheritance work
  __call = function (cls)
    local self = setmetatable({}, cls)
    UnitTest:_init(self)
    return self
  end
})

local ItemsTest = {}
ItemsTest.__index = ItemsTest

setmetatable(ItemsTest, {
  __index = UnitTest, -- this is what makes the inheritance work
  __call = function (cls)
    local self = setmetatable({}, cls)
    UnitTest:_init(self)
    return self
  end
})

local DestroyusProMainTest = {}
DestroyusProMainTest.__index = DestroyusProMainTest

setmetatable(DestroyusProMainTest, {
  __index = UnitTest, -- this is what makes the inheritance work
  __call = function (cls)
    local self = setmetatable({}, cls)
    UnitTest:_init(self)
    return self
  end
})

function HerbsAndOreTest.test_requiredStackAmountForMillingProspecting(self)
    self:assertEquals(DestroyusPro:isStackAmountEnough(1), 
	                  false, "Stack 1 should not be enough")
    self:assertEquals(DestroyusPro:isStackAmountEnough(5), 
	                  true, "Stack 5 should be enough")
    self:assertEquals(DestroyusPro:isStackAmountEnough(4),
	                  false, "Stack 4 should not be enough")
    self:assertEquals(DestroyusPro:isStackAmountEnough(6),
	                  true, "Stack 6 should be enough")
end

function HerbsAndOreTest.NOtest_isHerb(self)
    self:assertEquals(DestroyusPro:isHerb("Trade Goods", "Herb"), true)
    self:assertEquals(DestroyusPro:isHerb("Trade Goods", "Metal & Stone"), false)
    self:assertEquals(DestroyusPro:isHerb("Weapons", "Herb"), false)
end

function HerbsAndOreTest.NOtest_isOre(self)
    self:assertEquals(DestroyusPro:isOre("Trade Goods", "Metal & Stone",
                                         2770), true)
    self:assertEquals(DestroyusPro:isOre("Trade Goods", "Metal & Stone",
                                         2840), false)
    self:assertEquals(DestroyusPro:isOre("Trade Goods", "Metal & Stone",
                                         72092), true)
    self:assertEquals(DestroyusPro:isOre("Weapons", "Metal & Stone",
                                         23425), false)
end

function HerbsAndOreTest.test_herbQualityAllowed(self)
    self:assertEquals(DestroyusPro:isQualityHerbAllowed(1), 
	                  true, "Quality 1 should be allowed")
    self:assertEquals(DestroyusPro:isQualityHerbAllowed(2),
	                  true, "Quality 2 should be allowed")
    self:assertEquals(DestroyusPro:isQualityHerbAllowed(0),
	                  false, "Quality 0 should not be allowed")
    self:assertEquals(DestroyusPro:isQualityHerbAllowed(3),
	                  false, "Quality 3 should be allowed")
end

function HerbsAndOreTest.test_isItemNotConsumable(self)
    self:assertEquals(DestroyusPro:isItemNotConsumable(109624), 
	                  false, "Items should not be consumable case 1") 
    self:assertEquals(DestroyusPro:isItemNotConsumable(109125),
	                  true, "Items should be consumable case 2")
    self:assertEquals(DestroyusPro:isItemNotConsumable(108353),
	                  false, "Items should not be consumable case 3")
    self:assertEquals(DestroyusPro:isItemNotConsumable(79010),
	                  true, "Items should be consumable case 4")
end

function HerbsAndOreTest.test_haveItemRequiredProfLvl(self)
	-- Gromsblood
    self:assertEquals(DestroyusPro:haveItemRequiredProfLvl(8846,
        773, DestroyusPro.herbsIlvl), true, "Gromsblood should have required prof lvl")
	-- Snow Lily
    self:assertEquals(DestroyusPro:haveItemRequiredProfLvl(79010,
        773, DestroyusPro.herbsIlvl), false, "Snow Lily should not have required prof lvl") 
	-- Fireweed
    self:assertEquals(DestroyusPro:haveItemRequiredProfLvl(109125,
        773, DestroyusPro.herbsIlvl), true, "Fireweed should have required prof lvl")
	-- Starlight Rose
    self:assertEquals(DestroyusPro:haveItemRequiredProfLvl(124105,
        773, DestroyusPro.herbsIlvl), true, "Starlight should have required prof lvl")
    self:assertEquals(DestroyusPro:haveItemRequiredProfLvl(55290,
        773, DestroyusPro.herbsIlvl), false, "Razorwind Broadaxe(Axe) should not have required prof lvl")		
end

function HerbsAndOreTest.test_isNotUniqueItem(self)
	self:assertEquals(DestroyusPro:isNotUniqueItem(8153, DestroyusPro.itemsIdNotForMilling), 
	                  false, "Items should not be unique!")
	self:assertEquals(DestroyusPro:isNotUniqueItem(79010, DestroyusPro.itemsIdNotForMilling),
	                  true, "Items should be unique!")
end

function HerbsAndOreTest.test_isItemNotSellable(self)
	-- Item is not for sell 
	self:assertEquals(DestroyusPro:isItemNotSellable(true),
	                  false, "Item should be unique and not for sell")
	-- Item is for sell
	self:assertEquals(DestroyusPro:isItemNotSellable(false),
	                  true, "Item should be unique and can be sold")
end

function HerbsAndOreTest.test_isItemMillingable(self)
	-- Herb which can not be millingable
	bagClass:setBagSlot(79010, 5, false)
	self:assertEquals(DestroyusPro:isItemMillingable(1, 1),
	                  false, "Herb can not be millingable")
	-- Stack size good and herb is millingable
	bagClass:setBagSlot(109125, 10, false)
	self:assertEquals(DestroyusPro:isItemMillingable(1, 1),
	                  true, "Stack size bad or herb is not millingable")
	-- Stack size small when herb is millingable
	bagClass:setBagSlot(109125, 4, false)
	self:assertEquals(DestroyusPro:isItemMillingable(1, 1),
	                  false, "Stack size should be 4 < 5!")  
	-- Lvl of prof skill is better than herb
	bagClass:setBagSlot(8846, 10, false)
	self:assertEquals(DestroyusPro:isItemMillingable(1, 1),
	                  true, "Skill lvl is lover than herb lvl")
	-- Low lvl skill 475 > proff lvl
	bagClass:setBagSlot(52983, 5, false)
	self:assertEquals(DestroyusPro:isItemMillingable(1, 1),
	                  false, "Herb can not be milled in current prof lvl")
	-- Item is not herb
	bagClass:setBagSlot(55290, 5, false)
	self:assertEquals(DestroyusPro:isItemMillingable(1, 1),
	                  false, "Item is not a herb!")   
					  
	-- Stack size good and herb is millingable. uncommon quality felwort
	bagClass:setBagSlot(124106, 10, false)
	self:assertEquals(DestroyusPro:isItemMillingable(1, 1), true, 
					  "Felwort uncommon quality should be selected as ok")
end

function HerbsAndOreTest.test_isItemProspectingable(self)
	-- Copper Ore
	bagClass:setBagSlot(2770, 5, false)
	self:assertEquals(DestroyusPro:isItemProspectingable(1, 1),
	                  true, "Copper ore should be Prospectable")
	-- Iron Ore and prof lvl are equals
	bagClass:setBagSlot(2772, 5, false)
	self:assertEquals(DestroyusPro:isItemProspectingable(1, 1),
	                  true, "Iron Ore and prof lvl should be equals") 
	-- Iron ore and prof lvl are equals, stack small
	bagClass:setBagSlot(2772, 4, false)
	self:assertEquals(DestroyusPro:isItemProspectingable(1, 1),
	                  false, "ron ore and prof lvl are equals, stack 4 < 5!") 
	-- Fel Iron Ore prof lvl to small
	bagClass:setBagSlot(23424, 5, false)
	self:assertEquals(DestroyusPro:isItemProspectingable(1, 1),
	                 false, "Fel Iron Ore should not have been noticed") 
	-- Ghost Iron Ore lvl to small
	bagClass:setBagSlot(72092, 5, false)
	self:assertEquals(DestroyusPro:isItemProspectingable(1, 1),
	                 false, "Ghost Iron Ore should not have been noticed")
	-- Copper Bar
	bagClass:setBagSlot(2840, 50, false)
	self:assertEquals(DestroyusPro:isItemProspectingable(1, 1),
	                  false, "Copper ore is not Prospectingable")
end

function HerbsAndOreTest.setUp(self)
	self.functionProfInfo = GetProfessionInfo
	GetProfessionInfo = GetProfessionInfoApi
	self.functionGetProf = GetProfessions
	GetProfessions = function() return 1,2,3,4,5,6,7 end
	----
	self.bagFunction =  GetContainerItemInfo
    GetContainerItemInfo = function(i, j) return bagClass:returnBagSlot(i, j) end
end

function HerbsAndOreTest.tearDown(self)
	GetProfessionInfo = self.functionProfInfo
	GetProfessions = self.functionGetProf
	GetContainerItemInfo = self.bagFunction
end

function ItemsTest.test_isItem(self)
	-- Sunspring Vest 106719
	bagClass:setBagSlot(106719, 1, false)
	self:assertEquals(DestroyusPro:isItem(self.itemApi:getClass(),
                 	  self.itemApi:getSubClass(), self.itemApi:getEquipSlot()),
	                  true, "Sunspring Vest should be seen as item!")
end

function ItemsTest.test_isWeapon(self)
	-- Sunspring Vest 106719
	bagClass:setBagSlot(106719, 1, false)
	self:assertEquals(DestroyusPro:isWeapon(self.itemApi:getClass(), self.itemApi:getSubClass()),
	                  false, "Sunspring Vest is a Armor!")
	-- Tracker's Musket of the Bandit 36643 )
	bagClass:setBagSlot(36643, 1, false)
	self:assertEquals(DestroyusPro:isWeapon(self.itemApi:getClass(), self.itemApi:getSubClass()),
	                  true, "Tracker's Musket of the Bandit should be Weapon!")
	-- Oval Ring of Stamina 36417 
	bagClass:setBagSlot(36417, 1, false)
	self:assertEquals(DestroyusPro:isWeapon(self.itemApi:getClass(), self.itemApi:getSubClass()),
	                  false, "Oval Ring of Stamina is a Miscellaneous!")

end

function ItemsTest.test_isArmor(self)
	-- Sunspring Vest 106719
	bagClass:setBagSlot(106719, 1, false)
	self:assertEquals(DestroyusPro:isArmor(self.itemApi:getClass(), self.itemApi:getSubClass()),
	                  true, "Sunspring Vest should be armor!")
	-- Tracker's Musket of the Bandit 36643 
	bagClass:setBagSlot(36643, 1, false)
	self:assertEquals(DestroyusPro:isArmor(self.itemApi:getClass(), self.itemApi:getSubClass()),
	                  false, "Tracker's Musket of the Bandit is Weapon!") 
	-- Oval Ring of Stamina 36417 
	bagClass:setBagSlot(36417, 1, false)
	self:assertEquals(DestroyusPro:isArmor(self.itemApi:getClass(), self.itemApi:getSubClass()),
	                  false, "Oval Ring of Stamina is a Miscellaneous!") 
	
end 

function ItemsTest.test_isMiscellaneous(self)
	-- Sunspring Vest 106719
	bagClass:setBagSlot(106719, 1, false)
	self:assertEquals(DestroyusPro:isMiscellaneous(self.itemApi:getClass(), self.itemApi:getSubClass(),
	                  self.itemApi:getEquipSlot()),
	                  false, "Sunspring Vest is armor!")
	-- Tracker's Musket of the Bandit 36643 
	bagClass:setBagSlot(36643, 1, false)
	self:assertEquals(DestroyusPro:isMiscellaneous(self.itemApi:getClass(), self.itemApi:getSubClass(),
	                 self.itemApi:getEquipSlot()),
	                 false, "Tracker's Musket of the Bandit is Weapon!")
	-- Oval Ring of Stamina 36417 
	bagClass:setBagSlot(36417, 1, false)
	self:assertEquals(DestroyusPro:isMiscellaneous(self.itemApi:getClass(), self.itemApi:getSubClass(),
                      self.itemApi:getEquipSlot()),
	                  true, "Oval Ring of Stamina should be a Miscellaneous!")
end 

function ItemsTest.test_getItemProffLvlToDisArmor(self)
	-- Sunspring Vest 106719
	bagClass:setBagSlot(106719, 1, false)
	self:assertEquals(DestroyusPro:getItemProffLvlToDis(self.itemApi:getILvl(), self.itemApi:getQuality()),
	                 1, "Prof lvl is different than 1!")
	self:assertEquals(DestroyusPro:getItemProffLvlToDis(nil, 3),
	                  DestroyusPro.numberNotExist, "Value does not exist! ")
	-- Holy Shroud 2721 rare
	bagClass:setBagSlot(2721, 1, false)
	self:assertEquals(DestroyusPro:getItemProffLvlToDis(self.itemApi:getILvl(), self.itemApi:getQuality()),
	                 75, "Prof lvl is different than 75!")
	-- Belt of the Blood Nova 50015 epic
	bagClass:setBagSlot(50015, 1, false)
	self:assertEquals(DestroyusPro:getItemProffLvlToDis(self.itemApi:getILvl(), self.itemApi:getQuality()),
	                  375, "Prof lvl is different than 375!") 	
end

function ItemsTest.test_getItemProffLvlToDisWeapon(self)
	-- Tracker's Musket of the Bandit 36643 
	bagClass:setBagSlot(36643, 1, false)
	self:assertEquals(DestroyusPro:getItemProffLvlToDis(self.itemApi:getILvl(), self.itemApi:getQuality()),
	                  325, "Value of weapon is different tan 325!")
	self:assertEquals(DestroyusPro:getItemProffLvlToDis(-1, 3),
	                  DestroyusPro.numberNotExist, "Number should not exist. Case 1")
	self:assertEquals(DestroyusPro:getItemProffLvlToDis(-1, 4),
	                  DestroyusPro.numberNotExist, "Number should not exist. Case 2")
	self:assertEquals(DestroyusPro:getItemProffLvlToDis(-1, 2),
	                  DestroyusPro.numberNotExist, "Number should not exist. Case 3")
	self:assertEquals(DestroyusPro:getItemProffLvlToDis(1, -1), 
	                  DestroyusPro.numberNotExist, "Number should not exist. Case 4")
end

function ItemsTest.test_getItemProffLvlToDisRing(self)
	-- Oval Ring of Stamina 36417 
	bagClass:setBagSlot(36417, 1, false)
	self:assertEquals(DestroyusPro:getItemProffLvlToDis(self.itemApi:getILvl(), self.itemApi:getQuality()),
	                  325, "Value is different than 325!")
end

function ItemsTest.test_isItemEquippable(self)
	-- Oval Ring of Stamina 36417 
	self:assertEquals(DestroyusPro:isItemEquippable(36417),
	                  true, "Ring can not be Equippable")
	-- Sunspring Vest 106719
	self:assertEquals(DestroyusPro:isItemEquippable(106719),
	                  true, "Chest can not be Equippable") 
	-- Gromsblood 8846
	self:assertEquals(DestroyusPro:isItemEquippable(8846),
	                  false, "This item should not be Equippable")
end

function ItemsTest.test_isOnlyOneMaxStack(self)
	-- Tracker's Musket of the Bandit 36643 
	bagClass:setBagSlot(36643, 1, false)
	self:assertEquals(DestroyusPro:isOnlyOneMaxStack(self.itemApi:getMaxStackSize()),
	                  true, "Item do not have one stack")
	-- Gromsblood 8846
	bagClass:setBagSlot(8846, 1, false)
	self:assertEquals(DestroyusPro:isOnlyOneMaxStack(self.itemApi:getMaxStackSize()),
	                 false, "Item should not be only one stack!")
end

function ItemsTest.test_isQualityAllowed(self)
	-- Tracker's Musket of the Bandit 36643 
	bagClass:setBagSlot(36643, 1, false)
	self:assertEquals(DestroyusPro:isQualityAllowed(self.itemApi:getQuality()),
	                  true, "Quality should be allowed!")
end

function ItemsTest.test_isItemDisenchantable(self) 
	local functionGetProfEnch = GetProfessions
	GetProfessions = function() return 2,3,1,4,5,6,7 end
	-- Sunspring Vest 106719
	bagClass:setBagSlot(106719, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Sunspring Vest 106719")
	-- Scorching Cloak 134634
	bagClass:setBagSlot(134634, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  false, "Scorching Cloak 134634")
	-- Monastic Ring of Stoicism  88638  UniqueId
	bagClass:setBagSlot(88638, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  false, "Monastic Ring of Stoicism  88638  UniqueId")
	-- Necropolis Breastplate 134729
	bagClass:setBagSlot(36397, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Necropolis Breastplate 134729")
	-- Belt of the Blood Nova 50015 Quality epic 
	bagClass:setBagSlot(50015, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  false, "Belt of the Blood Nova 50015 Quality epic") 
	-- Jacinth Circle 11969
	bagClass:setBagSlot(11969, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Jacinth Circle 11969")
	-- Hypnotist's Watch 25786 Trinket 225 ILVL
	bagClass:setBagSlot(25786, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  true, "Hypnotist's Watch 25786 Trinket 225 ILVL")
	GetProfessions = functionGetProfEnch
	
end

function ItemsTest.test_isItemDisenchantableLowLvlSkill(self) 
	local functionGetProfEnch = GetProfessions
	GetProfessions = function() return 2,4,1,4,5,6,7 end
	-- Sunspring Vest 106719
	bagClass:setBagSlot(106719, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Sunspring Vest 106719")
	-- Scorching Cloak 134634
	bagClass:setBagSlot(134634, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  false, "Scorching Cloak 134634")
	-- Monastic Ring of Stoicism  88638  UniqueId
	bagClass:setBagSlot(88638, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  false, "Monastic Ring of Stoicism  88638  UniqueId")
	-- Necropolis Breastplate 36397
	bagClass:setBagSlot(36397, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1), 
	                  false, "Necropolis Breastplate 36397")
	-- Belt of the Blood Nova 50015 Quality epic 
	bagClass:setBagSlot(50015, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  false, "Belt of the Blood Nova 50015 Quality epic") 
	-- Jacinth Circle 11969
	bagClass:setBagSlot(11969, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  false, "Jacinth Circle 11969")
	-- Vindicator's Iron Legguards 26033 1 lvl disenchanting and armor
	bagClass:setBagSlot(26033, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Vindicator's Iron Legguards 26033 1 lvl disenchanting and armor")
	GetProfessions = functionGetProfEnch

end

function ItemsTest.test_isItemDisenchantableTranslateItems(self)
	local functionGetProfEnch = GetProfessions
	GetProfessions = function() return 2,4,1,4,5,6,7 end 
	-- Emergency Hatchet 69223 One Hand Axe
	bagClass:setBagSlot(69223, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Emergency Hatchet 69223 One Hand Axe") 
	-- Lupine Axe 1220 Two Hand Axe
	bagClass:setBagSlot(1220, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Lupine Axe 1220 Two Hand Axe")
	-- Shipwreck Bow 52646 Bow
	bagClass:setBagSlot(52646, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Shipwreck Bow 52646 Bow")
	-- Skorn's Rifle 3079 Gun
	bagClass:setBagSlot(3079, 1, false)	
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Skorn's Rifle 3079 Gun")
	--Gnoll Punisher 1214 One Hand Mace
	bagClass:setBagSlot(1214, 1, false)	
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  true, "Gnoll Punisher 1214 One Hand Mace")
	-- Codex Breaker 62878 Two Hand Mace
	bagClass:setBagSlot(62878, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  true, "Codex Breaker 62878 Two Hand Mace")
	-- Stunted Tree Root 57214 Polearms
	bagClass:setBagSlot(57214, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  true, "Stunted Tree Root 57214 Polearms")
	-- Sunwell Blade 22783 One Hand Sword
	bagClass:setBagSlot(22783, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  true, "Sunwell Blade 22783 One Hand Sword")
	-- Brashclaw's Skewer 2204 Two hand Sword
	bagClass:setBagSlot(2204, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  true, "Brashclaw's Skewer 2204 Two hand Sword")
	-- Gnarled Hermit's Staff 1539 Staff
	bagClass:setBagSlot(1539, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
			          true, "Gnarled Hermit's Staff 1539 Staff")
	-- Filthy Paw  58978 Fist Weapon
	bagClass:setBagSlot(58978, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Filthy Paw  58978 Fist Weapon")
	-- Venom Web Fang  899 Dagger
	bagClass:setBagSlot(899, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Venom Web Fang  899 Dagger")
	-- Shrewd Crossbow  59582 Xbow
	bagClass:setBagSlot(59582, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Shrewd Crossbow  59582 Xbow")
	-- Brazie's Plant Light 65689 Wand
	bagClass:setBagSlot(65689, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Brazie's Plant Light 65689 Wand")
	_G["DestroyusProItemQualityValue"] = DestroyusPro.strToNumQuality["rare"]
	-- Glaive of the Fallen 141604 Warglaives
	bagClass:setBagSlot(141604, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1), 
	                  true, "Glaive of the Fallen 141604 Warglaives")
	_G["DestroyusProItemQualityValue"] = DestroyusPro.strToNumQuality["uncommon"]
	GetProfessions = functionGetProfEnch
end

function ItemsTest.test_isItemDisenchantableTranslateArmor(self)
	local functionGetProfEnch = GetProfessions
	GetProfessions = function() return 2,4,1,4,5,6,7 end 
	-- Blue Overalls 6263 Cloth Armor
	bagClass:setBagSlot(6263, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  true, "Blue Overalls 6263 Cloth Armor")
	-- Dark Leather Tunic 2317 Leather Armor
	bagClass:setBagSlot(2317, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  true, "Dark Leather Tunic 2317 Leather Armor")
	-- Ironforge Breastplate 6731 Mail Armor
	bagClass:setBagSlot(6731, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  true, "Ironforge Breastplate 6731 Mail Armor")
	-- Stabilized Incendicite Legguards 59066 Plate
	bagClass:setBagSlot(59066, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Stabilized Incendicite Legguards 59066 Plate")
	-- Wheel of the Lost Hope 24334 Shield
	bagClass:setBagSlot(24334, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Wheel of the Lost Hope 24334 Shield")
	-- Greenweave Cloak 9770 back
	bagClass:setBagSlot(9770, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Greenweave Cloak 9770 back")
	GetProfessions = functionGetProfEnch
end

function ItemsTest.test_isItemDisenchantableTranslateMiscellaneous(self)
	local functionGetProfEnch = GetProfessions
	GetProfessions = function() return 2,4,1,4,5,6,7 end 
	-- Malachite Pendant 25438 Neck
	bagClass:setBagSlot(25438, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Malachite Pendant 25438 Neck")
	-- Windrunner Band 62892 Ring
	bagClass:setBagSlot(62892, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Windrunner Band 62892 Ring")
	-- Hypnotist's Watch 25786 Trinket 225 ILVL
	bagClass:setBagSlot(25786, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  false, "Hypnotist's Watch 25786 Trinket 225 ILVL")
	-- Glowing Murloc Eye 52652 Off Hand
	bagClass:setBagSlot(52652, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
					  true, "Glowing Murloc Eye 52652 Off Hand")
	GetProfessions = functionGetProfEnch
end

function ItemsTest.test_isFoundBug(self)
	-- Fixed ugly bug which exist from the beginning of the addon. 
	-- Current fault appeared when Enchanting profession was learned 
	-- as primary and secondary profession had lover/higher skill level
    -- than primary or does not exist.
	local functionGetProfEnch = GetProfessions
	GetProfessions = function() return 10,9,999,4,5,6,7 end 
	-- Hypnotist's Watch 25786 
	bagClass:setBagSlot(25786, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  true, "Hypnotist's Watch 25786 Bug Test")
	GetProfessions = functionGetProfEnch
end

function ItemsTest.test_professionNotExist(self)
	local functionGetProfEnch = GetProfessions
	GetProfessions = function() return nil,nil,999,4,5,6,7 end 
	-- Hypnotist's Watch 25786  
	bagClass:setBagSlot(25786, 1, false)
	self:assertEquals(DestroyusPro:isItemDisenchantable(1, 1),
	                  false, "Hypnotist's Watch 25786 Bug Test")
	GetProfessions = functionGetProfEnch
end

function ItemsTest.test_isNotUniqueItem(self) 
	-- Monastic Ring of Stoicism  88638  UniqueId
	self:assertEquals(DestroyusPro:isNotUniqueItem(88638, DestroyusPro.itemsIdNotForDisenchant),
	                  false, "Monastic Ring of Stoicism  88638  UniqueId")
	self:assertEquals(DestroyusPro:isNotUniqueItem(38289, DestroyusPro.itemsIdNotForDisenchant),
	                  false, "Item should be unqiue!") 
	self:assertEquals(DestroyusPro:isNotUniqueItem(55290, DestroyusPro.itemsIdNotForDisenchant),
	                  true, "Item should not be unique!")
end

function ItemsTest.setUp(self)
	self.functionProfInfo = GetProfessionInfo
	GetProfessionInfo = GetProfessionInfoApi
	self.functionGetProf = GetProfessions
	GetProfessions = function() return 1,2,3,4,5,6,7 end
	----
	self.bagFunction =  GetContainerItemInfo
    GetContainerItemInfo = function(i, j) return bagClass:returnBagSlot(i, j) end
	self.itemApi = _DPContainerItemApi()
	self.itemApi:setItemPos(1,1)
end

function ItemsTest.tearDown(self)
	GetProfessionInfo = self.functionProfInfo
	GetProfessions = self.functionGetProf
	GetContainerItemInfo = self.bagFunction 
end

function DestroyusProMainTest.setUp(self)
	self.functionProfInfo = GetProfessionInfo
	GetProfessionInfo = GetProfessionInfoApi
	self.functionGetProf = GetProfessions
	GetProfessions = function() return 1,2,3,4,5,6,7 end
	----
	self.bagFunction =  GetContainerItemInfo
    GetContainerItemInfo = function(i, j) return bagClass:returnBagSlot(i, j) end
	----
	self.GetContainerNumSlots = GetContainerNumSlots
	self.GetContainerNumSlots = function() return 20 end
end

function DestroyusProMainTest.tearDown(self)
	GetProfessionInfo = self.functionProfInfo
	GetProfessions = self.functionGetProf
	GetContainerItemInfo = self.bagFunction
	----
	GetContainerNumSlots = self.GetContainerNumSlots
end

function DestroyusProMainTest.test_createMacroInscription(self)
	-- i =3, j = 12
	bagClass:setBagSlot(36907, 10, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMilling)
	local macro = string.format("/cast %s\n/use 3 12", _DPSpellApi(_DPSpellApi.spellMilling):getSpellName())
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMilling , result), macro,
					  "Macro have not proper string value")
	-- Herb found. Low lvl profession lvl.
	bagClass:setBagSlot(52985, 10, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMilling)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMilling , result), "",
					  "Macro have not proper string value")
end

function DestroyusProMainTest.test_createMacroProspecting(self)
	-- i = 3, j = 12
	bagClass:setBagSlot(2772, 10, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellProspecting)
	local macro = string.format("/cast %s\n/use 3 12", _DPSpellApi(_DPSpellApi.spellProspecting):getSpellName())
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellProspecting , result), macro,
					  "Macro have not proper string value")
	-- Ore found. Low lvl profession lvl.
	bagClass:setBagSlot(53038, 10, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellProspecting)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellProspecting , result), "",
					  "Macro have not proper string value")
end

function DestroyusProMainTest.test_createMacroEnchanting(self)
	GetProfessions = function() return 10,nil,3,4,5,6,7 end
	-- i = 3, j = 12
	bagClass:setBagSlot(36499, 10, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellDisenchant)
	local macro = string.format("/cast %s\n/use 3 12", _DPSpellApi(_DPSpellApi.spellDisenchant):getSpellName())
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellDisenchant , result), macro,
					  "Macro have not proper string value")
	-- Item found. Low lvl profession lvl.
	bagClass:setBagSlot(55380, 10, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellDisenchant)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellDisenchant , result), "",
					  "Macro have not proper string value")
end

function DestroyusProMainTest.test_createMacroInscriptionMassMillingLegion(self)
	-- i =3, j = 12
	bagClass:setBagSlot(124101, 20, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillAethril)
	local macro = string.format("/cast %s\n/use 3 12", _DPSpellApi(_DPSpellApi.spellMassMillAethril):getSpellName())
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillAethril , result), macro,
					  "Macro have not proper string value. Aethril Mass Milling")
	-- Herb found. Low stack size
	bagClass:setBagSlot(124101, 19, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillAethril)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillAethril , result), "",
					  "Macro should be empty. Aethril Mass Millinge")
	-- i =3, j = 12
	bagClass:setBagSlot(124102, 20, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillDreamleaf)
	local macro = string.format("/cast %s\n/use 3 12", _DPSpellApi(_DPSpellApi.spellMassMillDreamleaf):getSpellName())
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillDreamleaf , result), macro,
					  "Macro have not proper string value. Dreamleaf Mass Milling")
	-- Herb found. Low stack size
	bagClass:setBagSlot(124102, 19, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillDreamleaf)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillDreamleaf , result), "",
					  "Macro should be empty. Dreamleaf Mass Millinge")
	-- i =3, j = 12
	bagClass:setBagSlot(124106, 20, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillFelwort)
	local macro = string.format("/cast %s\n/use 3 12", _DPSpellApi(_DPSpellApi.spellMassMillFelwort):getSpellName())
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillFelwort , result), macro,
					  "Macro have not proper string value. Felwort Mass Milling")
	-- Herb found. Low stack size
	bagClass:setBagSlot(124106, 19, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillFelwort)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillFelwort , result), "",
					  "Macro should be empty. Felwort Mass Millinge")	
	-- i =3, j = 12
	bagClass:setBagSlot(124104, 20, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillFjarnskaggl)
	local macro = string.format("/cast %s\n/use 3 12", _DPSpellApi(_DPSpellApi.spellMassMillFjarnskaggl):getSpellName())
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillFjarnskaggl , result), macro,
					  "Macro have not proper string value. Fjarnskaggl Mass Milling")
	-- Herb found. Low stack size
	bagClass:setBagSlot(124104, 19, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillFjarnskaggl)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillFjarnskaggl , result), "",
					  "Macro should be empty. Fjarnskaggl Mass Millinge")
	-- i =3, j = 12
	bagClass:setBagSlot(124103, 20, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillFoxflower)
	local macro = string.format("/cast %s\n/use 3 12", _DPSpellApi(_DPSpellApi.spellMassMillFoxflower):getSpellName())
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillFoxflower , result), macro,
					  "Macro have not proper string value. Foxflower Mass Milling")
	-- Herb found. Low stack size
	bagClass:setBagSlot(124103, 19, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillFoxflower)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillFoxflower , result), "",
					  "Macro should be empty. Foxflower Mass Millinge")
	-- i =3, j = 12
	bagClass:setBagSlot(124105, 20, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillStarlightRose)
	local macro = string.format("/cast %s\n/use 3 12", _DPSpellApi(_DPSpellApi.spellMassMillStarlightRose):getSpellName())
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillStarlightRose , result), macro,
					  "Macro have not proper string value. Starlight Rose Mass Milling")
	-- Herb found. Low stack size
	bagClass:setBagSlot(124105, 19, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillStarlightRose)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillStarlightRose , result), "",
					  "Macro should be empty. Starlight Rose Mass Millinge")
	-- i =3, j = 12		  
	bagClass:setBagSlot(128304, 20, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillYserallineSeeds)
	local macro = string.format("/cast %s\n/use 3 12", _DPSpellApi(_DPSpellApi.spellMassMillYserallineSeeds):getSpellName())
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillYserallineSeeds , result), macro,
					  "Macro have not proper string value. Yseralline Seed Rose Mass Milling")
	-- Herb found. Low stack size
	bagClass:setBagSlot(128304, 19, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillYserallineSeeds)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillYserallineSeeds , result), "",
					  "Macro should be empty. Yseralline Seed Rose Mass Millinge")
end

function DestroyusProMainTest.test_createMacroInscriptionMassMillingLegionAnotherItem(self)
	-- i =3, j = 12
	-- Ore should not be noticed. Stack size ok. 
	bagClass:setBagSlot(53038, 20, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillAethril)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillAethril , result), "",
					  "Macro should be empty. Ore is not Millinge")
	-- Ore should not be noticed
	bagClass:setBagSlot(53038, 19, false)
	local result = DestroyusProMain.findItemToWork(_DPSpellApi.spellMassMillAethril)
	self:assertEquals(DestroyusProMain.createMacroUsage(_DPSpellApi.spellMassMillAethril , result), "",
					  "Macro should be empty. Ore is not Millinge")
					  
end

function DestroyusProMainTest.test_collectMassMillingSpell(self)
	local savedFun = GetSpellBookItemInfo
	GetSpellBookItemInfo = GetSpellBookItemInfoApi
	local expectedSpell = {_DPSpellApi.spellMassMillAethril, _DPSpellApi.spellMassMillFjarnskaggl,
						   _DPSpellApi.spellMassMillYserallineSeeds}
	self:assertShallowTableEquals(DestroyusProMain.collectMassMillingSpell(), expectedSpell,
							"Speels id's are different")
	GetSpellBookItemInfo = savedFun
end

function DestroyusProMainTest.test_collectAllMassMillingSpell(self)
	local savedFun = GetSpellBookItemInfo
	GetSpellBookItemInfo = GetSpellBookItemInfoAllApi
	local expectedSpell =  {_DPSpellApi.spellMassMillAethril,
	_DPSpellApi.spellMassMillDreamleaf,
	_DPSpellApi.spellMassMillFelwort,
	_DPSpellApi.spellMassMillFjarnskaggl,
	_DPSpellApi.spellMassMillFoxflower,
	_DPSpellApi.spellMassMillStarlightRose,
	_DPSpellApi.spellMassMillYserallineSeeds}
	self:assertShallowTableEquals(DestroyusProMain.collectMassMillingSpell(), expectedSpell,
							"Speels id's are different")
	GetSpellBookItemInfo = savedFun
end

function DestroyusProMainTest.test_findItemToWorkMassMillingLegionNotAllSpellExist(self)
	local savedFun = GetSpellBookItemInfo
	GetSpellBookItemInfo = GetSpellBookItemInfoApi
	-- i =3, j = 12
	bagClass:setBagSlot(124101, 20, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], true, 
					 "Item found should be true Aethril Mass Milling")
	self:assertEquals(result["i"], 3, 
					 "I pos should be 3 Aethril Mass Milling")
	self:assertEquals(result["j"], 12, 
					 "j pos should be 12 Aethril Mass Milling")
	bagClass:setBagSlot(124105, 20, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], false, 
					 "Item found should be false Starlight Rose Mass Milling")
	self:assertEquals(result["i"], 0, 
					 "I pos should be 0 Starlight Rose Milling")
	self:assertEquals(result["j"], 0, 
					 "j pos should be 0 Starlight Rose Milling")	
	self:assertEquals(result["link"], "", 
					 "Link should be empty Starlight Rose Milling")							 
	GetSpellBookItemInfo = savedFun
end

function DestroyusProMainTest.test_findItemToWorkMassMillingLegionAllSpellExist(self)
	local savedFun = GetSpellBookItemInfo
	GetSpellBookItemInfo = GetSpellBookItemInfoAllApi
	-- i =3, j = 12
	bagClass:setBagSlot(124101, 20, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], true, 
					 "Item found should be true Aethril Mass Milling")
	self:assertEquals(result["i"], 3, 
					 "I pos should be 3 Aethril Mass Milling")
	self:assertEquals(result["j"], 12, 
					 "j pos should be 12 Aethril Mass Milling")
					 
	bagClass:setBagSlot(124105, 20, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], true, 
					 "Item found should be true Starlight Rose Mass Milling")
	self:assertEquals(result["i"], 3, 
					 "I pos should be 3 Starlight Rose Milling")
	self:assertEquals(result["j"], 12, 
					 "j pos should be 12 Starlight Rose Milling")
					 
	bagClass:setBagSlot(124105, 19, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], false, 
					 "Item found should be false Starlight Rose Mass Milling")
	self:assertEquals(result["i"], 0, 
					 "I pos should be 0 Starlight Rose Milling")
	self:assertEquals(result["j"], 0, 
					 "j pos should be 0 Starlight Rose Milling")	
	self:assertEquals(result["link"], "", 
					 "Link should be empty Starlight Rose Milling")	
	
	bagClass:setBagSlot(124102, 20, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], true, 
					 "Item found should be true Dreamleaf Mass Milling")
	self:assertEquals(result["i"], 3, 
					 "I pos should be 3 Dreamleaf Milling")
	self:assertEquals(result["j"], 12, 
					 "j pos should be 12 Dreamleaf Milling")
	
	bagClass:setBagSlot(124106, 20, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], true, 
					 "Item found should be true Felwort Mass Milling")
	self:assertEquals(result["i"], 3, 
					 "I pos should be 3 Felwort Milling")
	self:assertEquals(result["j"], 12, 
					 "j pos should be 12 Felwort Milling")
	
	bagClass:setBagSlot(124104, 20, false) 
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], true, 
					 "Item found should be true Fjarnskaggl Mass Milling")
	self:assertEquals(result["i"], 3, 
					 "I pos should be 3 Fjarnskaggl Milling")
	self:assertEquals(result["j"], 12, 
					 "j pos should be 12 Fjarnskaggl Milling")

	bagClass:setBagSlot(124103, 20, false) 
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], true, 
					 "Item found should be true Foxflower Mass Milling")
	self:assertEquals(result["i"], 3, 
					 "I pos should be 3 Foxflower Milling")
	self:assertEquals(result["j"], 12, 
					 "j pos should be 12 Foxflower Milling")
					 
	bagClass:setBagSlot(128304, 20, false) 
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], true, 
					 "Item found should be true Yseralline Seed Mass Milling")
	self:assertEquals(result["i"], 3, 
					 "I pos should be 3 Yseralline Seed Milling")
	self:assertEquals(result["j"], 12, 
					 "j pos should be 12 Yseralline Seed Milling")
	
	GetSpellBookItemInfo = savedFun
end

function DestroyusProMainTest.test_findItemToWorkMassMillingLegionSpellsNotExist(self)
	local savedFun = GetSpellBookItemInfo
	GetSpellBookItemInfo = function(name) return nil end
	-- i =3, j = 12
	bagClass:setBagSlot(124101, 20, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], false, 
					 "Item found should be false Aethril Mass Milling")
	self:assertEquals(result["i"], 0, 
					 "I pos should be 0 Aethril Mass Milling")
	self:assertEquals(result["j"], 0, 
					 "j pos should be 0 Aethril Mass Milling")
					 
	bagClass:setBagSlot(124105, 20, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], false, 
					 "Item found should be false Starlight Rose Mass Milling")
	self:assertEquals(result["i"], 0, 
					 "I pos should be 0 Starlight Rose Milling")
	self:assertEquals(result["j"], 0, 
					 "j pos should be 12 Starlight Rose Milling")
					 
	bagClass:setBagSlot(124105, 19, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], false, 
					 "Item found should be false Starlight Rose Mass Milling")
	self:assertEquals(result["i"], 0, 
					 "I pos should be 0 Starlight Rose Milling")
	self:assertEquals(result["j"], 0, 
					 "j pos should be 0 Starlight Rose Milling")	
	self:assertEquals(result["link"], "", 
					 "Link should be empty Starlight Rose Milling")	
	
	bagClass:setBagSlot(124102, 20, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], false, 
					 "Item found should be false Dreamleaf Mass Milling")
	self:assertEquals(result["i"], 0, 
					 "I pos should be 0 Dreamleaf Milling")
	self:assertEquals(result["j"], 0, 
					 "j pos should be 0 Dreamleaf Milling")
	
	bagClass:setBagSlot(124106, 20, false)
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], false, 
					 "Item found should be false Felwort Mass Milling")
	self:assertEquals(result["i"], 0, 
					 "I pos should be 0 Felwort Milling")
	self:assertEquals(result["j"], 0, 
					 "j pos should be 0 Felwort Milling")
	
	bagClass:setBagSlot(124104, 20, false) 
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], false, 
					 "Item found should be false Fjarnskaggl Mass Milling")
	self:assertEquals(result["i"], 0, 
					 "I pos should be 0 Fjarnskaggl Milling")
	self:assertEquals(result["j"], 0, 
					 "j pos should be 0 Fjarnskaggl Milling")

	bagClass:setBagSlot(124103, 20, false) 
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], false, 
					 "Item found should be false Foxflower Mass Milling")
	self:assertEquals(result["i"], 0, 
					 "I pos should be 0 Foxflower Milling")
	self:assertEquals(result["j"], 0, 
					 "j pos should be 0 Foxflower Milling")
					 
	bagClass:setBagSlot(128304, 20, false) 
	local result = DestroyusProMain.findItemToWorkMassMilling()
	self:assertEquals(result["itemFound"], false, 
					 "Item found should be false Yseralline Seed Mass Milling")
	self:assertEquals(result["i"], 0, 
					 "I pos should be 0 Yseralline Seed Milling")
	self:assertEquals(result["j"], 0, 
					 "j pos should be 0 Yseralline Seed Milling")
	
	GetSpellBookItemInfo = savedFun
end


function RunTest()
	utr = UnitTestRunner()
	utr:with(HerbsAndOreTest())
	utr:with(ItemsTest())
	utr:with(DestroyusProMainTest())
	utr:run()
end